<?php

/**
 * Plugin Name: Die GemeindeApp-Integration
 * Version: 0.5.2
 * Requires PHP: 7.0
 * License: MIT
 * Author: Martin Mühlpfordt, Patongo UG (haftungsbeschränkt)
 */

define( 'GEMEINDE_APP_VERSION', '0.5.2' );
define( 'GEMEINDE_APP_TYPES', array('posting','event','group'));
define( 'GEMEINDE_APP_TYPE_SLUGS', array(
	'posting' => 'aushaenge',
	'group'   => 'gruppen',
	'event'   => 'termine'  # only used for filter-routes as rewrite rules are setup by event_organiser
));
define( 'GEMEINDE_APP_TAXONOMIES', array(
	'main_topics' => [
		'singular'    => 'main_topic',
		'filter_slug' => 'thema',
		'labels'      => ['name' => 'Hauptthemen', 'singular_name' => 'Hauptthema', 'all' => 'Alle Themen'],
		],
	'main_audiences' => [
		'singular'    => 'main_audience',
		'filter_slug' => 'zielgruppe',
		'labels'      => ['name' => 'Hauptzielgruppen', 'singular_name' => 'Hauptzielgruppe', 'all' => 'Alle Zielgruppen'],
		]
));

define( 'GEMEINDE_APP_DIR', plugin_dir_path( __FILE__ ) );
define( 'GEMEINDE_APP_TEMPLATES_DIR', plugin_dir_path( __FILE__ ) . 'templates/' );
define( 'GEMEIMDE_APP_DEFAULT_AUDIENCE_COLOR', '#6c3493');
define( 'GEMEIMDE_APP_DEFAULT_AUDIENCE_NAME', 'Alle');

add_action( 'after_setup_theme', function(){
  if ( ! defined( 'GEMEINDE_APP_URL' ) ) {
		define( 'GEMEINDE_APP_URL', plugin_dir_url( __FILE__ ) );
	}
} );

require_once(plugin_dir_path( __FILE__ ) . 'includes/model.php' );
require_once(plugin_dir_path( __FILE__ ) . 'includes/templates.php' );
require_once(plugin_dir_path( __FILE__ ) . 'includes/filter-routes.php' );
require_once(plugin_dir_path( __FILE__ ) . 'includes/shortcodes.php' );
require_once(plugin_dir_path( __FILE__ ) . 'includes/event-organiser-rest-api.php' );
require_once(plugin_dir_path( __FILE__ ) . 'functions.php' );

add_action( 'admin_init', function(){
	if ( is_admin() && current_user_can( 'activate_plugins' )) {
		add_action( 'admin_notices', function() {
			$requirements = array(
				'advanced-custom-fields/acf.php'        => "Advanced Custom Fields",
				'event-organiser/event-organiser.php'   => "Event Organiser",
				'user-role-editor/user-role-editor.php' => "User Role Editor",
			);

			// error_log("[ADMIN_INIT] Check required plugins");
			$missing = array();
			foreach ($requirements as $plugin => $name) {
				if (!is_plugin_active( $plugin )) { $missing[]=$name; }
			}
			// error_log("[ADMIN_INIT] Missing plugins: ". implode(', ', $missing));
			if(!empty($missing)) {
				// error_log("[ADMIN_INIT] Setup admin_notices");
				echo('<div class="error"><p>Bitte installieren und aktivieren Sie folgende(s) Plugin(s): ' . implode(', ', $missing) . '</p></div>');
			}
		});
	}
});
