<?php

add_action( 'init', function () {

  register_post_type( "posting", array(
   'labels'                => ["name" => "Aushänge", "singular_name" => "Aushang", ],
   'has_archive'           => true,
   'menu_icon'             => 'dashicons-bell',
   'rest_base'             => "postings",

   'rewrite'               => ["slug" => GEMEINDE_APP_TYPE_SLUGS['posting'], "with_front" => false ],
   'delete_with_user'      => false,
   'description'           => "",
   'map_meta_cap'          => true,
   'menu_position'         => 4,
   'public'                => true,
   'query_var'             => true,
   'show_in_rest'          => true,
   'supports'              => [ "title", "editor", "thumbnail", "custom-fields", "contact_person" ],
   'taxonomies'            => array_keys(GEMEINDE_APP_TAXONOMIES),
   'template'              => [],
   'template_lock'         => 'all',
 ));

  register_post_type( "group", array(
   'labels'                => ["name" => "Gemeindegruppen", "singular_name" => "Gemeindegruppe", ],
   'has_archive'           => true,
   'menu_icon'             => 'dashicons-groups',
   'rest_base'             => "groups",
   'rewrite'               => [ "slug" => GEMEINDE_APP_TYPE_SLUGS['group'], "with_front" => false ],

   'delete_with_user'      => false,
   'description'           => "",
   'map_meta_cap'          => true,
   'menu_position'         => 4,
   'public'                => true,
   'query_var'             => true,
   'show_in_rest'          => true,
   'supports'              => [ "title", "editor", "thumbnail", "custom-fields", "contact_person" ],
   'taxonomies'            => array_keys(GEMEINDE_APP_TAXONOMIES),
   'template'              => [],
   'template_lock'         => 'all',
  ));

  foreach(GEMEINDE_APP_TAXONOMIES as $taxonomy => $tax_defs) {
		register_taxonomy( $taxonomy, GEMEINDE_APP_TYPES, array(
	    'labels'                => $tax_defs['labels'],
	    'rest_base'             => $taxonomy,
	    'public'                => true,
	    'show_ui'               => false,
	    'show_in_nav_menus'     => false,
	    'show_in_rest'          => true,
	  ));
	}

});

add_action( 'rest_api_init', function () {
  // Register further meta-fields.
  // They will all show up in all post types (posts, events, groups)
  register_meta('post', 'contact_person', array(
      'type'         => 'string',
      'description'  => 'Name einer Kontaktperson.',
      'single'       => true,
      'show_in_rest' => true,
  ));
  register_meta('post', 'app_url', array(
      'type'         => 'string',
      'description'  => 'Deep-Link in Die GemeindeApp.',
      'single'       => true,
      'show_in_rest' => true,
  ));
  register_meta('post', 'main_image_url', array(
      'type'         => 'string',
      'description'  => 'URL des Titelbildes.',
      'single'       => true,
      'show_in_rest' => true,
  ));
  register_meta('post', 'main_image_copyright', array(
      'type'         => 'string',
      'description'  => 'Urheberinformation zum Titelbild.',
      'single'       => true,
      'show_in_rest' => true,
  ));
  register_meta('post', 'post_type', array(
      'type'         => 'string',
      'description'  => 'The type of this post: announcement, article, or challenge.',
      'single'       => true,
      'show_in_rest' => true,
  ));
  // We add the meta fields to ALL categories, as adding to main_topics and main_audiences only does not work
  register_term_meta( '', 'color', array(
      'type'         => 'string',
      'description'  => 'Kategorienfarbe',
      'single'       => true,
      'show_in_rest' => true,
  ));

  register_term_meta('', 'svg_icon', array(
      'type'         => 'string',
      'description'  => 'Kategorien-Icon als SVG',
      'single'       => true,
      'show_in_rest' => true,
  ));

  register_rest_field( 'posting', 'event', array(
      'get_callback'    => function( $post ) { return get_field("event", $post['id'] ); },
      'update_callback' => function( $event_id, $post ) { update_field("event", $event_id, $post->ID);},
      'schema'          => array(
            'description' => __( 'Event ID.' ),
            'type'        => 'integer' ),
  ));

  $group_field_spec = array(
      'get_callback' => function( $post ) { return get_field("group", $post['id'] ); },
      'update_callback' => function( $group_id, $post ) { update_field("group", $group_id, $post->ID);},
      'schema' => array(
          'description' => __( 'Group ID.' ),
          'type'        => 'integer'
      ),
  );
  register_rest_field( 'posting', 'group',  $group_field_spec);
  register_rest_field( 'event', 'group', $group_field_spec);
  }
);
