<?php

/**
 * The [gemeinde_app_entries] shortcode.
 *
 * - Liste der Aushänge einer Gruppe 	  [gemeinde_app_entries post_type=posting group=...]
 * - Liste der Aushänge zu MainTopic    [gemeinde_app_entries post_type=posting main_topic=...]
 * - Liste der Aushänge zu MainAudience [gemeinde_app_entries post_type=posting main_audience=...]
 * - Verweis auf einen konkreten Beitrag  [gemeinde_app_entries post_type=posting name=....], wobei unter name dann der Slug des Beitrags angegeben werden muss.
 *
 * == Attributes: ==
 * - post_type: posting, event, group
 * - main_topic: (string) – Titel eines Hauptthemas
 * - main_audience: (string) - Titel einer Hauptzielgruppe
 *
 * @param array  $atts    Shortcode attributes.
 * @param string $content Shortcode empty note. Default null.
 * @return string Shortcode output.
 */
function gemeinde_app_entries_shortcode( $atts = [], $content = null ) {
	# 1. Build query
	// normalize attribute keys, lowercase
	$atts = array_change_key_case( (array) $atts, CASE_LOWER );
	$query = wp_parse_args($atts, array(
		'post_type'        => 'posting',
		'posts_per_page'   => 5,
		'paged'            => 1, # always inline ((get_query_var('paged')) ? get_query_var('paged') : 1), // Current page
		'tax_query'    		 => array(),
	));

	$style = "";
	if(isset($query['style'])){
		$style = $query['style'];
		unset($query['style']);
	}
	if(isset($query['group'])){
		$query['meta_key'] = 'group';
		$query['meta_value'] = $query['group'];
		unset($query['group']);
	}

	if(!empty($query['main_audience'])) {
		$query['tax_query'][] = array (
			'taxonomy' => 'main_audiences',
			'field' 	 => 'name',
			'terms' 	 => sanitize_text_field($query['main_audience']),
		);
		unset($query['main_audience']);
	}

	if(!empty($query['main_topic'])) {
		$query['tax_query'][] = array (
			'taxonomy' => 'main_topics',
			'field' 	 => 'name',
			'terms' 	 => sanitize_text_field($query['main_topic']),
		);
		unset($query['main_topic']);
	}

	if ($query['post_type'] === 'event') {
		# Enhance query with arguments for Event Organiser.
		# Translate meta_keys
		$query = wp_parse_args($query, array(
			'suppress_filters' => false,
			'orderby'          => 'eventstart',
			'order'            => 'ASC',
			'group_events_by'  => 'occurrences', // WARNING: you get loading times up to minutes when using 'series'!   ‘series’ or ‘occurrences’. Defaults to ‘occurrences’ (effectively no grouping). If set to ‘series’, only the next occurrence of a recurring event is displayed.
			'showpastevents'   => false,
		));
	} else {
		$query = wp_parse_args($query, array(
//			'orderby'          => 'date', DEFAULT
//			'order'            => 'DESC', DEFAULT
		));
	}

	$gemeinde_app_loop = new WP_Query( $query );

	ob_start();

	echo '<div class="previews-list ' . $style . '">';
//	echo '<code class="debug-template">' . print_r($query) . '</code>';
	if ( $gemeinde_app_loop->have_posts() ) {
		while( $gemeinde_app_loop->have_posts() ): $gemeinde_app_loop->the_post();
			get_gemeinde_app_template_part('preview', get_post_type());
		endwhile;
	} else {
		if (!empty($content))
				echo $content;
		else
				echo "Keine Beiträge";
	}
	echo '</div>';

	$html = ob_get_contents();
	ob_end_clean();
	wp_reset_postdata();
	return $html;
}

function the_gemeinde_app_filter_meta_entry($term, $taxonomy) {
	// <i></i><span>label</span>
	$icon_class = ($taxonomy == 'main_audiences') ? 'main-audience' : 'main-topic';
	if (empty($term)) {
		echo '<i class="meta-info '. $icon_class.'"></i><span>'. GEMEINDE_APP_TAXONOMIES[$taxonomy]['labels']['all'] .'</span>';
	} else {
		if ($taxonomy == 'main_audiences') {
			$color = get_main_meta($term, 'color');
			echo '<i class="' . $icon_class . '" style="--audience-color:'. $color .'"></i><span>'. $term->name .'</span>';
		} else {
			$svg = get_main_meta($term, 'svg_icon');
			echo '<i class="' . $icon_class . '">'. $svg .'</i><span>'. $term->name .'</span>';
		}
	}
}

function the_gemeinde_app_filter_meta_select_entry($term, $taxonomy, $post_type, $current_query_params) {
	$tax_singular = GEMEINDE_APP_TAXONOMIES[$taxonomy]['singular'];
	if (empty($term)) {
		$query_params = array_diff_key($current_query_params, [$tax_singular => ''] );
	} else {
		$query_params = array_merge($current_query_params, [$tax_singular => ($term->slug)]);
	}
	$url = '/' . GEMEINDE_APP_TYPE_SLUGS[$post_type] . '/?' . http_build_query( $query_params );
	// <li><a href="url"><i></i><span>label</span></a></li>
	echo '<li><a href="'. $url .'">'; the_gemeinde_app_filter_meta_entry($term, $taxonomy); echo '</a></li>';
}
/**
 * The [gemeinde_app_filter] shortcode.
 *
 * - Filter im aktuellen Bereich nach Themen 	  	[gemeinde_app_filter by=main_topics type=event]
 * - Filter im aktuellen Bereich nach Zielgruppe 	[gemeinde_app_filter by=main_audiences type=posting]
 *
 * == Attributes: ==
 * - by: (string) main_topics, main_audiences
 * - type: (string) event, posting
 *
 * @param array  $atts    Shortcode attributes.
 * @param string $content Shortcode empty note. Default null.
 * @return string Shortcode output.
 */
function gemeinde_app_filter_shortcode( $atts = [], $content = null ) {
	$atts = array_change_key_case( (array) $atts, CASE_LOWER );
	$taxonomy = $atts['by'];
	if (empty($taxonomy)) { return ""; }
	$terms = get_terms(array('taxonomy' => $taxonomy, 'hide_empty' => true));
	if ( empty( $terms ) || ! is_array( $terms ) ) { return ""; }

	$post_type = $atts['type'];
	if (empty($post_type)) { $post_type = get_post_type(); }

	$current_query_params = array();
	foreach (GEMEINDE_APP_TAXONOMIES as $tax => $tax_defs) {
		$key = $tax_defs['singular'];
		$val = get_query_var( $key );
		if (!empty($val)) {$current_query_params[$key] = get_query_var( $key );}
	}

	$tax_singular = GEMEINDE_APP_TAXONOMIES[$taxonomy]['singular'];
	$currently_selected = isset($current_query_params[$tax_singular]) ? $current_query_params[$tax_singular] : null;
	$currently_selected_term = get_term_by('slug', $currently_selected, $taxonomy);

	ob_start();

	/*
	<div class="gemeinde-app-filter">
		<div class="selected"><i></i><span>label</span></div>
		<ul class="entries">
			<li><a href="url"><i></i><span>label</span></a></li>
		</ul>
	</div>
	*/
	echo '<div class="gemeinde-app-filter gemeinde-app-entry">';
		echo '<div class="selected">'; the_gemeinde_app_filter_meta_entry($currently_selected_term, $taxonomy); echo '</div>';
		echo '<ul>';
			the_gemeinde_app_filter_meta_select_entry([], $taxonomy, $post_type, $current_query_params);
			foreach ( $terms as $key=>$term ) {
				the_gemeinde_app_filter_meta_select_entry($term, $taxonomy, $post_type, $current_query_params);
			}
		echo '</ul>';
	echo '</div>';

/*		echo '<select class="gemeinde-app-filter" onchange="if (this.value) window.location.href=this.value">';
			$url = '/' . GEMEINDE_APP_TYPE_SLUGS[$post_type] . '/?' . http_build_query( array_diff_key($current_query_params, [$tax_singular => ''] ));
			$selected = empty($current_query_params[$tax_singular]) ? ' selected' : '';
			echo '<option value="'. $url .'" '. $selected . '>' . GEMEINDE_APP_TAXONOMIES[$taxonomy]['labels']['all'] . '</option>';
			foreach ( $terms as $key=>$term ) {
				$query_params = array_merge($current_query_params, [$tax_singular => ($term->slug)]);
				$url = '/' . GEMEINDE_APP_TYPE_SLUGS[$post_type] . '/?' . http_build_query( $query_params );
				$selected = ($term->slug === $currently_selected) ? ' selected' : '';
				echo '<option value="'. $url .'" '. $selected . '>' . $term->name . '</option>';
			}
		echo '</select>';
*/
	$html = ob_get_contents();
	ob_end_clean();
	wp_reset_postdata();
	return $html;
}

add_action( 'init', function(){
	add_shortcode( 'gemeinde_app_entries', 'gemeinde_app_entries_shortcode' );
	add_shortcode( 'gemeinde_app_filter',  'gemeinde_app_filter_shortcode');
} );
